# partialwrap

partialwrap: A small Python library providing wrappers for external
             executables and Python functions so that they can easily be
             partialised with Python's functools.partial.

Created Mars 2020 by Matthias Cuntz.

It is distributed under the MIT License (see LICENSE file and below).

Copyright (c) 2016-2020 Matthias Cuntz

## Main Author

- [Matthias Cuntz](https://github.com/mcuntz), E-mail: mc (at) macu (dot) de

## Contributing Authors

- [Sebastian Müller](https://github.com/MuellerSeb)
